@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2016 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -27,7 +27,7 @@ import sys
 
 # Global name
 __appname__ = 'glances'
-__version__ = '2.6.1'
+__version__ = '2.7.1'
 __author__ = 'Nicolas Hennion <nicolas@nicolargo.com>'
 __license__ = 'LGPL'
 
@@ -49,16 +49,13 @@ except locale.Error:
     print("Warning: Unable to set locale. Expect encoding problems.")
 
 # Check Python version
-if sys.version_info < (2, 6) or (3, 0) <= sys.version_info < (3, 3):
-    print('Glances requires at least Python 2.6 or 3.3 to run.')
-    sys.exit(1)
-
 if sys.version_info[:2] == (2, 6):
     import warnings
-    warnings.warn('Python 2.6 support will be dropped. Please switch '
-                  'to at least Python 2.7 or 3.3+ as soon as possible. '
-                  'See http://www.snarky.ca/stop-using-python-2-6 '
-                  'for more information.')
+    warnings.warn('Python 2.6 support is dropped. Please switch to at '
+                  'least Python 2.7/3.3+ or downgrade to Glances 2.6.2.')
+if sys.version_info < (2, 7) or (3, 0) <= sys.version_info < (3, 3):
+    print('Glances requires at least Python 2.7 or 3.3 to run.')
+    sys.exit(1)
 
 # Check PSutil version
 psutil_min_version = (2, 0, 0)
@@ -103,8 +100,8 @@ def main():
     Run it...
     """
     # Log Glances and PSutil version
-    logger.info('Start Glances {0}'.format(__version__))
-    logger.info('{0} {1} and PSutil {2} detected'.format(
+    logger.info('Start Glances {}'.format(__version__))
+    logger.info('{} {} and PSutil {} detected'.format(
         platform.python_implementation(),
         platform.python_version(),
         psutil_version))
@@ -175,7 +172,7 @@ def main():
         server = GlancesServer(cached_time=core.cached_time,
                                config=core.get_config(),
                                args=args)
-        print('Glances server is running on {0}:{1}'.format(args.bind_address, args.port))
+        print('Glances server is running on {}:{}'.format(args.bind_address, args.port))
 
         # Set the server login/password (if -P/--password tag)
         if args.password != "":
