@@ -39,7 +39,7 @@ class GlancesMain(object):
     refresh_time = 3
 
     # Set the default cache lifetime to 1 second (only for server)
-    # !!! Todo: configuration from the command line
+    # !!! Todo: To be configurable (=> https://github.com/nicolargo/glances/issues/901)
     cached_time = 1
     # By default, Glances is ran in standalone mode (no client/server)
     client_tag = False
@@ -114,10 +114,14 @@ Start the client browser (browser mode):\n\
                             dest='disable_load', help='disable load module')
         parser.add_argument('--disable-network', action='store_true', default=False,
                             dest='disable_network', help='disable network module')
+        parser.add_argument('--disable-ports', action='store_true', default=False,
+                            dest='disable_ports', help='disable ports scanner module')
         parser.add_argument('--disable-ip', action='store_true', default=False,
                             dest='disable_ip', help='disable IP module')
         parser.add_argument('--disable-diskio', action='store_true', default=False,
                             dest='disable_diskio', help='disable disk I/O module')
+        parser.add_argument('--disable-irq', action='store_true', default=False,
+                            dest='disable_irq', help='disable IRQ module'),
         parser.add_argument('--disable-fs', action='store_true', default=False,
                             dest='disable_fs', help='disable filesystem module')
         parser.add_argument('--disable-folder', action='store_true', default=False,
@@ -138,23 +142,29 @@ Start the client browser (browser mode):\n\
                             help='disable network, disk I/O, FS and sensors modules')
         parser.add_argument('--disable-process', action='store_true', default=False,
                             dest='disable_process', help='disable process module')
+        parser.add_argument('--disable-amps', action='store_true', default=False,
+                            dest='disable_amps', help='disable applications monitoring process (AMP) module')
         parser.add_argument('--disable-log', action='store_true', default=False,
                             dest='disable_log', help='disable log module')
+        parser.add_argument('--disable-history', action='store_true', default=False,
+                            dest='disable_history', help='disable stats history')
         parser.add_argument('--disable-bold', action='store_true', default=False,
                             dest='disable_bold', help='disable bold mode in the terminal')
         parser.add_argument('--disable-bg', action='store_true', default=False,
                             dest='disable_bg', help='disable background colors in the terminal')
         parser.add_argument('--enable-process-extended', action='store_true', default=False,
                             dest='enable_process_extended', help='enable extended stats on top process')
-        parser.add_argument('--enable-history', action='store_true', default=False,
-                            dest='enable_history', help='enable the history mode (matplotlib needed)')
-        parser.add_argument('--path-history', default=tempfile.gettempdir(),
-                            dest='path_history', help='set the export path for graph history')
         # Export modules feature
+        parser.add_argument('--export-graph', action='store_true', default=None,
+                            dest='export_graph', help='export stats to graphs')
+        parser.add_argument('--path-graph', default=tempfile.gettempdir(),
+                            dest='path_graph', help='set the export path for graphs (default is {0})'.format(tempfile.gettempdir()))
         parser.add_argument('--export-csv', default=None,
                             dest='export_csv', help='export stats to a CSV file')
         parser.add_argument('--export-influxdb', action='store_true', default=False,
                             dest='export_influxdb', help='export stats to an InfluxDB server (influxdb lib needed)')
+        parser.add_argument('--export-cassandra', action='store_true', default=False,
+                            dest='export_cassandra', help='export stats to a Cassandra or Scylla server (cassandra lib needed)')
         parser.add_argument('--export-opentsdb', action='store_true', default=False,
                             dest='export_opentsdb', help='export stats to an OpenTSDB server (potsdb lib needed)')
         parser.add_argument('--export-statsd', action='store_true', default=False,
@@ -175,7 +185,7 @@ Start the client browser (browser mode):\n\
         parser.add_argument('--disable-autodiscover', action='store_true', default=False,
                             dest='disable_autodiscover', help='disable autodiscover feature')
         parser.add_argument('-p', '--port', default=None, type=int, dest='port',
-                            help='define the client/server TCP port [default: {0}]'.format(self.server_port))
+                            help='define the client/server TCP port [default: {}]'.format(self.server_port))
         parser.add_argument('-B', '--bind', default='0.0.0.0', dest='bind_address',
                             help='bind server to the given IPv4/IPv6 address or hostname')
         parser.add_argument('--username', action='store_true', default=False, dest='username_prompt',
@@ -195,7 +205,7 @@ Start the client browser (browser mode):\n\
         parser.add_argument('--snmp-force', action='store_true', default=False,
                             dest='snmp_force', help='force SNMP mode')
         parser.add_argument('-t', '--time', default=self.refresh_time, type=float,
-                            dest='time', help='set refresh time in seconds [default: {0} sec]'.format(self.refresh_time))
+                            dest='time', help='set refresh time in seconds [default: {} sec]'.format(self.refresh_time))
         parser.add_argument('-w', '--webserver', action='store_true', default=False,
                             dest='webserver', help='run Glances in web server mode (bottle needed)')
         # Display options
@@ -206,7 +216,7 @@ Start the client browser (browser mode):\n\
         parser.add_argument('--process-short-name', action='store_true', default=False,
                             dest='process_short_name', help='force short name for processes name')
         parser.add_argument('-0', '--disable-irix', action='store_true', default=False,
-                            dest='disable_irix', help='Task\'s cpu usage will be divided by the total number of CPUs')
+                            dest='disable_irix', help='task\'s cpu usage will be divided by the total number of CPUs')
         if not WINDOWS:
             parser.add_argument('--hide-kernel-threads', action='store_true', default=False,
                                 dest='no_kernel_threads', help='hide kernel threads in process list')
@@ -227,7 +237,9 @@ Start the client browser (browser mode):\n\
                             dest='fs_free_space', help='display FS free space instead of used')
         parser.add_argument('--theme-white', action='store_true', default=False,
                             dest='theme_white', help='optimize display colors for white background')
-
+        # Globals options
+        parser.add_argument('--disable-check-update', action='store_true', default=False,
+                            dest='disable_check_update', help='disable online Glances version ckeck')
         return parser
 
     def parse_args(self):
@@ -276,17 +288,17 @@ Start the client browser (browser mode):\n\
             # Interactive or file password
             if args.server:
                 args.password = self.__get_password(
-                    description='Define the Glances server password ({0} username): '.format(args.username),
+                    description='Define the Glances server password ({} username): '.format(args.username),
                     confirm=True,
                     username=args.username)
             elif args.webserver:
                 args.password = self.__get_password(
-                    description='Define the Glances webserver password ({0} username): '.format(args.username),
+                    description='Define the Glances webserver password ({} username): '.format(args.username),
                     confirm=True,
                     username=args.username)
             elif args.client:
                 args.password = self.__get_password(
-                    description='Enter the Glances server password ({0} username): '.format(args.username),
+                    description='Enter the Glances server password ({} username): '.format(args.username),
                     clear=True,
                     username=args.username)
         else:
@@ -322,7 +334,7 @@ Start the client browser (browser mode):\n\
         self.args = args
 
         # Export is only available in standalone or client mode (issue #614)
-        export_tag = args.export_csv or args.export_elasticsearch or args.export_statsd or args.export_influxdb or args.export_opentsdb or args.export_rabbitmq
+        export_tag = args.export_csv or args.export_elasticsearch or args.export_statsd or args.export_influxdb or args.export_cassandra or args.export_opentsdb or args.export_rabbitmq
         if not (self.is_standalone() or self.is_client()) and export_tag:
             logger.critical("Export is only available in standalone or client mode")
             sys.exit(2)
@@ -333,11 +345,16 @@ Start the client browser (browser mode):\n\
             sys.exit(2)
 
         # Check graph output path
-        if args.enable_history and args.path_history is not None:
-            if not os.access(args.path_history, os.W_OK):
-                logger.critical("History output path {0} do not exist or is not writable".format(args.path_history))
+        if args.export_graph and args.path_graph is not None:
+            if not os.access(args.path_graph, os.W_OK):
+                logger.critical("Graphs output path {0} do not exist or is not writable".format(args.path_graph))
                 sys.exit(2)
-            logger.debug("History output path is set to {0}".format(args.path_history))
+            logger.debug("Graphs output path is set to {0}".format(args.path_graph))
+
+        # For export graph, history is mandatory
+        if args.export_graph and args.disable_history:
+            logger.critical("Can not export graph if history is disabled")
+            sys.exit(2)
 
         # Disable HDDTemp if sensors are disabled
         if args.disable_sensors:
