@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2016 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -19,19 +19,18 @@
 
 """Curses interface class."""
 
-# Import system lib
 import re
 import sys
 
-# Import Glances lib
-from glances.core.glances_globals import is_mac, is_windows
-from glances.core.glances_logging import logger
-from glances.core.glances_logs import glances_logs
-from glances.core.glances_processes import glances_processes
-from glances.core.glances_timer import Timer
+from glances.compat import u
+from glances.globals import OSX, WINDOWS
+from glances.logger import logger
+from glances.logs import glances_logs
+from glances.processes import glances_processes
+from glances.timer import Timer
 
 # Import curses lib for "normal" operating system and consolelog for Windows
-if not is_windows:
+if not WINDOWS:
     try:
         import curses
         import curses.panel
@@ -52,8 +51,9 @@ class _GlancesCurses(object):
     Note: It is a private class, use GlancesCursesClient or GlancesCursesBrowser.
     """
 
-    def __init__(self, args=None):
-        # Init args
+    def __init__(self, config=None, args=None):
+        # Init
+        self.config = config
         self.args = args
 
         # Init windows positions
@@ -70,61 +70,134 @@ class _GlancesCurses(object):
             logger.critical("Cannot init the curses library.\n")
             sys.exit(1)
 
-        # Set curses options
-        if hasattr(curses, 'start_color'):
-            curses.start_color()
-        if hasattr(curses, 'use_default_colors'):
-            curses.use_default_colors()
+        # Load the 'outputs' section of the configuration file
+        # - Init the theme (default is black)
+        self.theme = {'name': 'black'}
+        self.load_config(self.config)
+
+        # Init cursor
+        self._init_cursor()
+
+        # Init the colors
+        self._init_colors()
+
+        # Init main window
+        self.term_window = self.screen.subwin(0, 0)
+
+        # Init refresh time
+        self.__refresh_time = args.time
+
+        # Init edit filter tag
+        self.edit_filter = False
+
+        # Init the process min/max reset
+        self.args.reset_minmax_tag = False
+
+        # Catch key pressed with non blocking mode
+        self.no_flash_cursor()
+        self.term_window.nodelay(1)
+        self.pressedkey = -1
+
+        # History tag
+        self._init_history()
+
+    def load_config(self, config):
+        '''Load the outputs section of the configuration file'''
+        # Load the theme
+        if config is not None and config.has_section('outputs'):
+            logger.debug('Read the outputs section in the configuration file')
+            self.theme['name'] = config.get_value('outputs', 'curse_theme', default='black')
+            logger.debug('Theme for the curse interface: {}'.format(self.theme['name']))
+
+    def is_theme(self, name):
+        '''Return True if the theme *name* should be used'''
+        return getattr(self.args, 'theme_' + name) or self.theme['name'] == name
+
+    def _init_history(self):
+        '''Init the history option'''
+
+        self.reset_history_tag = False
+        self.graph_tag = False
+        if self.args.export_graph:
+            logger.info('Export graphs function enabled with output path %s' %
+                        self.args.path_graph)
+            from glances.exports.graph import GlancesGraph
+            self.glances_graph = GlancesGraph(self.args.path_graph)
+            if not self.glances_graph.graph_enabled():
+                self.args.export_graph = False
+                logger.error('Export graphs disabled')
+
+    def _init_cursor(self):
+        '''Init cursors'''
+
         if hasattr(curses, 'noecho'):
             curses.noecho()
         if hasattr(curses, 'cbreak'):
             curses.cbreak()
         self.set_cursor(0)
 
+    def _init_colors(self):
+        '''Init the Curses color layout'''
+
+        # Set curses options
+        if hasattr(curses, 'start_color'):
+            curses.start_color()
+        if hasattr(curses, 'use_default_colors'):
+            curses.use_default_colors()
+
         # Init colors
-        self.hascolors = False
-        if curses.has_colors() and curses.COLOR_PAIRS > 8:
-            self.hascolors = True
-            # FG color, BG color
-            if args.theme_white:
-                curses.init_pair(1, curses.COLOR_BLACK, -1)
-            else:
-                curses.init_pair(1, curses.COLOR_WHITE, -1)
-            curses.init_pair(2, curses.COLOR_WHITE, curses.COLOR_RED)
-            curses.init_pair(3, curses.COLOR_WHITE, curses.COLOR_GREEN)
-            curses.init_pair(4, curses.COLOR_WHITE, curses.COLOR_BLUE)
-            curses.init_pair(5, curses.COLOR_WHITE, curses.COLOR_MAGENTA)
-            curses.init_pair(6, curses.COLOR_RED, -1)
-            curses.init_pair(7, curses.COLOR_GREEN, -1)
-            curses.init_pair(8, curses.COLOR_BLUE, -1)
-            try:
-                curses.init_pair(9, curses.COLOR_MAGENTA, -1)
-            except Exception:
-                if args.theme_white:
-                    curses.init_pair(9, curses.COLOR_BLACK, -1)
-                else:
-                    curses.init_pair(9, curses.COLOR_WHITE, -1)
-            try:
-                curses.init_pair(10, curses.COLOR_CYAN, -1)
-            except Exception:
-                if args.theme_white:
-                    curses.init_pair(10, curses.COLOR_BLACK, -1)
-                else:
-                    curses.init_pair(10, curses.COLOR_WHITE, -1)
-
-        else:
-            self.hascolors = False
-
-        if args.disable_bold:
-            A_BOLD = curses.A_BOLD
-        else:
+        if self.args.disable_bold:
             A_BOLD = 0
+            self.args.disable_bg = True
+        else:
+            A_BOLD = curses.A_BOLD
 
         self.title_color = A_BOLD
         self.title_underline_color = A_BOLD | curses.A_UNDERLINE
         self.help_color = A_BOLD
-        if self.hascolors:
+
+        if curses.has_colors():
+            # The screen is compatible with a colored design
+            if self.is_theme('white'):
+                # White theme: black ==> white
+                curses.init_pair(1, curses.COLOR_BLACK, -1)
+            else:
+                curses.init_pair(1, curses.COLOR_WHITE, -1)
+            if self.args.disable_bg:
+                curses.init_pair(2, curses.COLOR_RED, -1)
+                curses.init_pair(3, curses.COLOR_GREEN, -1)
+                curses.init_pair(4, curses.COLOR_BLUE, -1)
+                curses.init_pair(5, curses.COLOR_MAGENTA, -1)
+            else:
+                curses.init_pair(2, curses.COLOR_WHITE, curses.COLOR_RED)
+                curses.init_pair(3, curses.COLOR_WHITE, curses.COLOR_GREEN)
+                curses.init_pair(4, curses.COLOR_WHITE, curses.COLOR_BLUE)
+                curses.init_pair(5, curses.COLOR_WHITE, curses.COLOR_MAGENTA)
+            curses.init_pair(6, curses.COLOR_RED, -1)
+            curses.init_pair(7, curses.COLOR_GREEN, -1)
+            curses.init_pair(8, curses.COLOR_BLUE, -1)
+
             # Colors text styles
+            if curses.COLOR_PAIRS > 8:
+                try:
+                    curses.init_pair(9, curses.COLOR_MAGENTA, -1)
+                except Exception:
+                    if self.is_theme('white'):
+                        curses.init_pair(9, curses.COLOR_BLACK, -1)
+                    else:
+                        curses.init_pair(9, curses.COLOR_WHITE, -1)
+                try:
+                    curses.init_pair(10, curses.COLOR_CYAN, -1)
+                except Exception:
+                    if self.is_theme('white'):
+                        curses.init_pair(10, curses.COLOR_BLACK, -1)
+                    else:
+                        curses.init_pair(10, curses.COLOR_WHITE, -1)
+
+                self.ifWARNING_color2 = curses.color_pair(9) | A_BOLD
+                self.ifCRITICAL_color2 = curses.color_pair(6) | A_BOLD
+                self.filter_color = curses.color_pair(10) | A_BOLD
+
             self.no_color = curses.color_pair(1)
             self.default_color = curses.color_pair(3) | A_BOLD
             self.nice_color = curses.color_pair(9) | A_BOLD
@@ -134,11 +207,10 @@ class _GlancesCurses(object):
             self.ifCRITICAL_color = curses.color_pair(2) | A_BOLD
             self.default_color2 = curses.color_pair(7) | A_BOLD
             self.ifCAREFUL_color2 = curses.color_pair(8) | A_BOLD
-            self.ifWARNING_color2 = curses.color_pair(9) | A_BOLD
-            self.ifCRITICAL_color2 = curses.color_pair(6) | A_BOLD
-            self.filter_color = curses.color_pair(10) | A_BOLD
+
         else:
-            # B&W text styles
+            # The screen is NOT compatible with a colored design
+            # switch to B&W text styles
             self.no_color = curses.A_NORMAL
             self.default_color = curses.A_NORMAL
             self.nice_color = A_BOLD
@@ -175,33 +247,6 @@ class _GlancesCurses(object):
             'PASSWORD': curses.A_PROTECT
         }
 
-        # Init main window
-        self.term_window = self.screen.subwin(0, 0)
-
-        # Init refresh time
-        self.__refresh_time = args.time
-
-        # Init edit filter tag
-        self.edit_filter = False
-
-        # Catch key pressed with non blocking mode
-        self.no_flash_cursor()
-        self.term_window.nodelay(1)
-        self.pressedkey = -1
-
-        # History tag
-        self.reset_history_tag = False
-        self.history_tag = False
-        if args.enable_history:
-            logger.info('Stats history enabled with output path %s' %
-                        args.path_history)
-            from glances.exports.glances_history import GlancesHistory
-            self.glances_history = GlancesHistory(args.path_history)
-            if not self.glances_history.graph_enabled():
-                args.enable_history = False
-                logger.error(
-                    'Stats history disabled because MatPlotLib is not installed')
-
     def flash_cursor(self):
         self.term_window.keypad(1)
 
@@ -277,6 +322,22 @@ class _GlancesCurses(object):
                 self.args.disable_cpu = False
                 self.args.disable_mem = False
                 self.args.disable_swap = False
+        elif self.pressedkey == ord('5'):
+            # '5' > Enable/disable top menu
+            logger.info(self.args.disable_top)
+            self.args.disable_top = not self.args.disable_top
+            if self.args.disable_top:
+                self.args.disable_quicklook = True
+                self.args.disable_cpu = True
+                self.args.disable_mem = True
+                self.args.disable_swap = True
+                self.args.disable_load = True
+            else:
+                self.args.disable_quicklook = False
+                self.args.disable_cpu = False
+                self.args.disable_mem = False
+                self.args.disable_swap = False
+                self.args.disable_load = False
         elif self.pressedkey == ord('/'):
             # '/' > Switch between short/long name for processes
             self.args.process_short_name = not self.args.process_short_name
@@ -284,10 +345,15 @@ class _GlancesCurses(object):
             # 'a' > Sort processes automatically and reset to 'cpu_percent'
             glances_processes.auto_sort = True
             glances_processes.sort_key = 'cpu_percent'
+        elif self.pressedkey == ord('A'):
+            # 'A' > enable/disable AMP module
+            self.args.disable_amps = not self.args.disable_amps
         elif self.pressedkey == ord('b'):
             # 'b' > Switch between bit/s and Byte/s for network IO
-            # self.net_byteps_tag = not self.net_byteps_tag
             self.args.byte = not self.args.byte
+        elif self.pressedkey == ord('B'):
+            # 'B' > Switch between bit/s and IO/s for Disk IO
+            self.args.diskio_iops = not self.args.diskio_iops
         elif self.pressedkey == ord('c'):
             # 'c' > Sort processes by CPU usage
             glances_processes.auto_sort = False
@@ -305,15 +371,20 @@ class _GlancesCurses(object):
                 glances_processes.disable_extended()
             else:
                 glances_processes.enable_extended()
+        elif self.pressedkey == ord('E'):
+            # 'E' > Erase the process filter
+            logger.info("Erase process filter")
+            glances_processes.process_filter = None
         elif self.pressedkey == ord('F'):
             # 'F' > Switch between FS available and free space
             self.args.fs_free_space = not self.args.fs_free_space
         elif self.pressedkey == ord('f'):
-            # 'f' > Show/hide fs stats
+            # 'f' > Show/hide fs / folder stats
             self.args.disable_fs = not self.args.disable_fs
+            self.args.disable_folder = not self.args.disable_folder
         elif self.pressedkey == ord('g'):
-            # 'g' > History
-            self.history_tag = not self.history_tag
+            # 'g' > Export graphs to file
+            self.graph_tag = not self.graph_tag
         elif self.pressedkey == ord('h'):
             # 'h' > Show/hide help
             self.args.help_tag = not self.args.help_tag
@@ -331,6 +402,9 @@ class _GlancesCurses(object):
             # 'm' > Sort processes by MEM usage
             glances_processes.auto_sort = False
             glances_processes.sort_key = 'memory_percent'
+        elif self.pressedkey == ord('M'):
+            # 'M' > Reset processes summary min/max
+            self.args.reset_minmax_tag = not self.args.reset_minmax_tag
         elif self.pressedkey == ord('n'):
             # 'n' > Show/hide network stats
             self.args.disable_network = not self.args.disable_network
@@ -338,6 +412,11 @@ class _GlancesCurses(object):
             # 'p' > Sort processes by name
             glances_processes.auto_sort = False
             glances_processes.sort_key = 'name'
+        elif self.pressedkey == ord('P'):
+            # 'P' > Disable ports scan plugins
+            self.args.disable_ports = not self.args.disable_ports
+        elif self.pressedkey == ord('Q'):
+            self.args.disable_irq = not self.args.disable_irq
         elif self.pressedkey == ord('r'):
             # 'r' > Reset history
             self.reset_history_tag = not self.reset_history_tag
@@ -368,7 +447,7 @@ class _GlancesCurses(object):
             # 'x' > Delete finished warning and critical logs
             glances_logs.clean(critical=True)
         elif self.pressedkey == ord('z'):
-            # 'z' > Enable/Disable processes stats (count + list + monitor)
+            # 'z' > Enable/Disable processes stats (count + list + AMPs)
             # Enable/Disable display
             self.args.disable_process = not self.args.disable_process
             # Enable/Disable update
@@ -460,6 +539,8 @@ class _GlancesCurses(object):
         stats_memswap = stats.get_plugin('memswap').get_stats_display(args=self.args)
         stats_network = stats.get_plugin('network').get_stats_display(
             args=self.args, max_width=plugin_max_width)
+        stats_irq = stats.get_plugin('irq').get_stats_display(
+            args=self.args, max_width=plugin_max_width)
         try:
             stats_ip = stats.get_plugin('ip').get_stats_display(args=self.args)
         except AttributeError:
@@ -468,17 +549,21 @@ class _GlancesCurses(object):
             'diskio').get_stats_display(args=self.args)
         stats_fs = stats.get_plugin('fs').get_stats_display(
             args=self.args, max_width=plugin_max_width)
+        stats_folders = stats.get_plugin('folders').get_stats_display(
+            args=self.args, max_width=plugin_max_width)
         stats_raid = stats.get_plugin('raid').get_stats_display(
             args=self.args)
         stats_sensors = stats.get_plugin(
             'sensors').get_stats_display(args=self.args)
+        stats_ports = stats.get_plugin(
+            'ports').get_stats_display(args=self.args)
         stats_now = stats.get_plugin('now').get_stats_display()
         stats_docker = stats.get_plugin('docker').get_stats_display(
             args=self.args)
         stats_processcount = stats.get_plugin(
             'processcount').get_stats_display(args=self.args)
-        stats_monitor = stats.get_plugin(
-            'monitor').get_stats_display(args=self.args)
+        stats_amps = stats.get_plugin(
+            'amps').get_stats_display(args=self.args)
         stats_alert = stats.get_plugin(
             'alert').get_stats_display(args=self.args)
 
@@ -495,7 +580,7 @@ class _GlancesCurses(object):
             max_processes_displayed = 0
         if (glances_processes.max_processes is None or
                 glances_processes.max_processes != max_processes_displayed):
-            logger.debug("Set number of displayed processes to {0}".format(max_processes_displayed))
+            logger.debug("Set number of displayed processes to {}".format(max_processes_displayed))
             glances_processes.max_processes = max_processes_displayed
 
         stats_processlist = stats.get_plugin(
@@ -628,24 +713,35 @@ class _GlancesCurses(object):
         self.saved_line = self.next_line
 
         # ==================================================================
-        # Display left sidebar (NETWORK+DISKIO+FS+SENSORS+Current time)
+        # Display left sidebar (NETWORK+PORTS+DISKIO+FS+SENSORS+Current time)
         # ==================================================================
         self.init_column()
-        if not (self.args.disable_network and self.args.disable_diskio and
-                self.args.disable_fs and self.args.disable_raid and
+        if not (self.args.disable_network and
+                self.args.disable_ports and
+                self.args.disable_diskio and
+                self.args.disable_fs and
+                self.args.disable_folder and
+                self.args.disable_raid and
                 self.args.disable_sensors) and not self.args.disable_left_sidebar:
             self.new_line()
             self.display_plugin(stats_network)
             self.new_line()
+            self.display_plugin(stats_ports)
+            self.new_line()
             self.display_plugin(stats_diskio)
             self.new_line()
             self.display_plugin(stats_fs)
             self.new_line()
+            self.display_plugin(stats_irq)
+            self.new_line()
+            self.display_plugin(stats_folders)
+            self.new_line()
             self.display_plugin(stats_raid)
             self.new_line()
             self.display_plugin(stats_sensors)
             self.new_line()
             self.display_plugin(stats_now)
+            self.new_line()
 
         # ====================================
         # Display right stats (process and co)
@@ -656,53 +752,61 @@ class _GlancesCurses(object):
             self.next_line = self.saved_line
 
             # Display right sidebar
-            # ((DOCKER)+PROCESS_COUNT+(MONITORED)+PROCESS_LIST+ALERT)
+            # DOCKER+PROCESS_COUNT+AMPS+PROCESS_LIST+ALERT
             self.new_column()
             self.new_line()
             self.display_plugin(stats_docker)
             self.new_line()
             self.display_plugin(stats_processcount)
-            if glances_processes.process_filter is None and cs_status is None:
-                # Do not display stats monitor list if a filter exist
-                self.new_line()
-                self.display_plugin(stats_monitor)
+            self.new_line()
+            self.display_plugin(stats_amps)
             self.new_line()
             self.display_plugin(stats_processlist,
                                 display_optional=(screen_x > 102),
-                                display_additional=(not is_mac),
+                                display_additional=(not OSX),
                                 max_y=(screen_y - self.get_stats_display_height(stats_alert) - 2))
             self.new_line()
             self.display_plugin(stats_alert)
 
         # History option
         # Generate history graph
-        if self.history_tag and self.args.enable_history:
+        if self.graph_tag and self.args.export_graph:
             self.display_popup(
                 'Generate graphs history in {0}\nPlease wait...'.format(
-                    self.glances_history.get_output_folder()))
+                    self.glances_graph.get_output_folder()))
             self.display_popup(
                 'Generate graphs history in {0}\nDone: {1} graphs generated'.format(
-                    self.glances_history.get_output_folder(),
-                    self.glances_history.generate_graph(stats)))
-        elif self.reset_history_tag and self.args.enable_history:
-            self.display_popup('Reset history')
-            self.glances_history.reset(stats)
-        elif (self.history_tag or self.reset_history_tag) and not self.args.enable_history:
+                    self.glances_graph.get_output_folder(),
+                    self.glances_graph.generate_graph(stats)))
+        elif self.reset_history_tag and self.args.export_graph:
+            self.display_popup('Reset graph history')
+            self.glances_graph.reset(stats)
+        elif (self.graph_tag or self.reset_history_tag) and not self.args.export_graph:
             try:
-                self.glances_history.graph_enabled()
+                self.glances_graph.graph_enabled()
             except Exception:
-                self.display_popup('History disabled\nEnable it using --enable-history')
+                self.display_popup('Graph disabled\nEnable it using --export-graph')
             else:
-                self.display_popup('History disabled\nPlease install matplotlib')
-        self.history_tag = False
+                self.display_popup('Graph disabled')
+        self.graph_tag = False
         self.reset_history_tag = False
 
         # Display edit filter popup
         # Only in standalone mode (cs_status is None)
         if self.edit_filter and cs_status is None:
             new_filter = self.display_popup(
-                'Process filter pattern: ', is_input=True,
-                input_value=glances_processes.process_filter)
+                'Process filter pattern: \n' +
+                '\n' +
+                'Examples:\n' +
+                '- python\n' +
+                '- .*python.*\n' +
+                '- \/usr\/lib.*' +
+                '- name:.*nautilus.*\n' +
+                '- cmdline:.*glances.*\n' +
+                '- username:nicolargo\n' +
+                '- username:^root        ',
+                is_input=True,
+                input_value=glances_processes.process_filter_input)
             glances_processes.process_filter = new_filter
         elif self.edit_filter and cs_status != 'None':
             self.display_popup('Process filter only available in standalone mode')
@@ -758,7 +862,7 @@ class _GlancesCurses(object):
         for y, m in enumerate(message.split('\n')):
             popup.addnstr(2 + y, 2, m, len(m))
 
-        if is_input and not is_windows:
+        if is_input and not WINDOWS:
             # Create a subwindow for the text field
             subpop = popup.derwin(1, input_size, 2, 2 + len(m))
             subpop.attron(self.colors_list['FILTER'])
@@ -785,7 +889,7 @@ class _GlancesCurses(object):
         else:
             # Display the popup
             popup.refresh()
-            curses.napms(duration * 1000)
+            self.wait(duration * 1000)
             return True
 
     def display_plugin(self, plugin_stats,
@@ -858,15 +962,15 @@ class _GlancesCurses(object):
                 pass
             else:
                 # New column
+                # Python 2: we need to decode to get real screen size because
+                # UTF-8 special tree chars occupy several bytes.
+                # Python 3: strings are strings and bytes are bytes, all is
+                # good.
                 try:
-                    # Python 2: we need to decode to get real screen size because utf-8 special tree chars
-                    # occupy several bytes
-                    offset = len(m['msg'].decode("utf-8", "replace"))
-                except AttributeError:
-                    # Python 3: strings are strings and bytes are bytes, all is
-                    # good
-                    offset = len(m['msg'])
-                x += offset
+                    x += len(u(m['msg']))
+                except UnicodeDecodeError:
+                    # Quick and dirty hack for issue #745
+                    pass
                 if x > x_max:
                     x_max = x
 
@@ -925,10 +1029,14 @@ class _GlancesCurses(object):
                 # Redraw display
                 self.flush(stats, cs_status=cs_status)
             # Wait 100ms...
-            curses.napms(100)
+            self.wait()
 
         return exitkey
 
+    def wait(self, delay=100):
+        """Wait delay in ms"""
+        curses.napms(100)
+
     def get_stats_display_width(self, curse_msg, without_option=False):
         """Return the width of the formatted curses message.
 
@@ -975,258 +1083,15 @@ class GlancesCursesClient(_GlancesCurses):
     pass
 
 
-class GlancesCursesBrowser(_GlancesCurses):
+if not WINDOWS:
+    class GlancesTextbox(Textbox, object):
 
-    """Class for the Glances curse client browser."""
-
-    def __init__(self, args=None):
-        # Init the father class
-        _GlancesCurses.__init__(self, args=args)
-
-        _colors_list = {
-            'UNKNOWN': self.no_color,
-            'SNMP': self.default_color2,
-            'ONLINE': self.default_color2,
-            'OFFLINE': self.ifCRITICAL_color2,
-            'PROTECTED': self.ifWARNING_color2,
-        }
-        self.colors_list.update(_colors_list)
-
-        # First time scan tag
-        # Used to display a specific message when the browser is started
-        self.first_scan = True
-
-        # Init refresh time
-        self.__refresh_time = args.time
-
-        # Init the cursor position for the client browser
-        self.cursor_position = 0
-
-        # Active Glances server number
-        self._active_server = None
-
-    @property
-    def active_server(self):
-        """Return the active server or None if it's the browser list."""
-        return self._active_server
-
-    @active_server.setter
-    def active_server(self, index):
-        """Set the active server or None if no server selected."""
-        self._active_server = index
-
-    @property
-    def cursor(self):
-        """Get the cursor position."""
-        return self.cursor_position
-
-    @cursor.setter
-    def cursor(self, position):
-        """Set the cursor position."""
-        self.cursor_position = position
-
-    def cursor_up(self, servers_list):
-        """Set the cursor to position N-1 in the list."""
-        if self.cursor_position > 0:
-            self.cursor_position -= 1
-        else:
-            self.cursor_position = len(servers_list) - 1
-
-    def cursor_down(self, servers_list):
-        """Set the cursor to position N-1 in the list."""
-        if self.cursor_position < len(servers_list) - 1:
-            self.cursor_position += 1
-        else:
-            self.cursor_position = 0
-
-    def __catch_key(self, servers_list):
-        # Catch the browser pressed key
-        self.pressedkey = self.get_key(self.term_window)
-
-        # Actions...
-        if self.pressedkey == ord('\x1b') or self.pressedkey == ord('q'):
-            # 'ESC'|'q' > Quit
-            self.end()
-            logger.info("Stop Glances client browser")
-            sys.exit(0)
-        elif self.pressedkey == 10:
-            # 'ENTER' > Run Glances on the selected server
-            logger.debug("Server number {0} selected".format(self.cursor + 1))
-            self.active_server = self.cursor
-        elif self.pressedkey == 259:
-            # 'UP' > Up in the server list
-            self.cursor_up(servers_list)
-        elif self.pressedkey == 258:
-            # 'DOWN' > Down in the server list
-            self.cursor_down(servers_list)
-
-        # Return the key code
-        return self.pressedkey
-
-    def update(self, servers_list):
-        """Update the servers' list screen.
-
-        Wait for __refresh_time sec / catch key every 100 ms.
-
-        servers_list: Dict of dict with servers stats
-        """
-        # Flush display
-        logger.debug('Servers list: {0}'.format(servers_list))
-        self.flush(servers_list)
-
-        # Wait
-        exitkey = False
-        countdown = Timer(self.__refresh_time)
-        while not countdown.finished() and not exitkey:
-            # Getkey
-            pressedkey = self.__catch_key(servers_list)
-            # Is it an exit or select server key ?
-            exitkey = (
-                pressedkey == ord('\x1b') or pressedkey == ord('q') or pressedkey == 10)
-            if not exitkey and pressedkey > -1:
-                # Redraw display
-                self.flush(servers_list)
-            # Wait 100ms...
-            curses.napms(100)
-
-        return self.active_server
-
-    def flush(self, servers_list):
-        """Update the servers' list screen.
-
-        servers_list: List of dict with servers stats
-        """
-        self.erase()
-        self.display(servers_list)
-
-    def display(self, servers_list):
-        """Display the servers list.
-
-        Return:
-            True if the stats have been displayed
-            False if the stats have not been displayed (no server available)
-        """
-        # Init the internal line/column for Glances Curses
-        self.init_line_column()
-
-        # Get the current screen size
-        screen_x = self.screen.getmaxyx()[1]
-        screen_y = self.screen.getmaxyx()[0]
-
-        # Init position
-        x = 0
-        y = 0
-
-        # Display top header
-        if len(servers_list) == 0:
-            if self.first_scan and not self.args.disable_autodiscover:
-                msg = 'Glances is scanning your network. Please wait...'
-                self.first_scan = False
-            else:
-                msg = 'No Glances server available'
-        elif len(servers_list) == 1:
-            msg = 'One Glances server available'
-        else:
-            msg = '{0} Glances servers available'.format(len(servers_list))
-        if self.args.disable_autodiscover:
-            msg += ' ' + '(auto discover is disabled)'
-        self.term_window.addnstr(y, x,
-                                 msg,
-                                 screen_x - x,
-                                 self.colors_list['TITLE'])
-
-        if len(servers_list) == 0:
-            return False
-
-        # Display the Glances server list
-        # ================================
-
-        # Table of table
-        # Item description: [stats_id, column name, column size]
-        column_def = [
-            ['name', 'Name', 16],
-            ['alias', None, None],
-            ['load_min5', 'LOAD', 6],
-            ['cpu_percent', 'CPU%', 5],
-            ['mem_percent', 'MEM%', 5],
-            ['status', 'STATUS', 9],
-            ['ip', 'IP', 15],
-            # ['port', 'PORT', 5],
-            ['hr_name', 'OS', 16],
-        ]
-        y = 2
-
-        # Display table header
-        xc = x + 2
-        for cpt, c in enumerate(column_def):
-            if xc < screen_x and y < screen_y and c[1] is not None:
-                self.term_window.addnstr(y, xc,
-                                         c[1],
-                                         screen_x - x,
-                                         self.colors_list['BOLD'])
-                xc += c[2] + self.space_between_column
-        y += 1
-
-        # If a servers has been deleted from the list...
-        # ... and if the cursor is in the latest position
-        if self.cursor > len(servers_list) - 1:
-            # Set the cursor position to the latest item
-            self.cursor = len(servers_list) - 1
-
-        # Display table
-        line = 0
-        for v in servers_list:
-            # Get server stats
-            server_stat = {}
-            for c in column_def:
-                try:
-                    server_stat[c[0]] = v[c[0]]
-                except KeyError as e:
-                    logger.debug(
-                        "Cannot grab stats {0} from server (KeyError: {1})".format(c[0], e))
-                    server_stat[c[0]] = '?'
-                # Display alias instead of name
-                try:
-                    if c[0] == 'alias' and v[c[0]] is not None:
-                        server_stat['name'] = v[c[0]]
-                except KeyError:
-                    pass
-
-            # Display line for server stats
-            cpt = 0
-            xc = x
-
-            # Is the line selected ?
-            if line == self.cursor:
-                # Display cursor
-                self.term_window.addnstr(
-                    y, xc, ">", screen_x - xc, self.colors_list['BOLD'])
-
-            # Display the line
-            xc += 2
-            for c in column_def:
-                if xc < screen_x and y < screen_y and c[1] is not None:
-                    # Display server stats
-                    self.term_window.addnstr(
-                        y, xc, format(server_stat[c[0]]), c[2], self.colors_list[v['status']])
-                    xc += c[2] + self.space_between_column
-                cpt += 1
-            # Next line, next server...
-            y += 1
-            line += 1
-
-        return True
-
-
-if not is_windows:
-    class GlancesTextbox(Textbox):
-
-        def __init__(*args, **kwargs):
-            Textbox.__init__(*args, **kwargs)
+        def __init__(self, *args, **kwargs):
+            super(GlancesTextbox, self).__init__(*args, **kwargs)
 
         def do_command(self, ch):
             if ch == 10:  # Enter
                 return 0
             if ch == 127:  # Back
                 return 8
-            return Textbox.do_command(self, ch)
+            return super(GlancesTextbox, self).do_command(ch)
