@@ -5,13 +5,15 @@ glancesApp.service('GlancesStats', function($http, $injector, $q, GlancesPlugin)
         'alert': 'GlancesPluginAlert',
         'cpu': 'GlancesPluginCpu',
         'diskio': 'GlancesPluginDiskio',
+	'irq'   : 'GlancesPluginIrq',
         'docker': 'GlancesPluginDocker',
         'ip': 'GlancesPluginIp',
         'fs': 'GlancesPluginFs',
+        'folders': 'GlancesPluginFolders',
         'load': 'GlancesPluginLoad',
         'mem': 'GlancesPluginMem',
         'memswap': 'GlancesPluginMemSwap',
-        'monitor': 'GlancesPluginMonitor',
+        'amps': 'GlancesPluginAmps',
         'network': 'GlancesPluginNetwork',
         'percpu': 'GlancesPluginPerCpu',
         'processcount': 'GlancesPluginProcessCount',
@@ -20,7 +22,8 @@ glancesApp.service('GlancesStats', function($http, $injector, $q, GlancesPlugin)
         'raid': 'GlancesPluginRaid',
         'sensors': 'GlancesPluginSensors',
         'system': 'GlancesPluginSystem',
-        'uptime': 'GlancesPluginUptime'
+        'uptime': 'GlancesPluginUptime',
+        'ports': 'GlancesPluginPorts'
     };
 
     this.getData = function() {
