@@ -24,13 +24,15 @@ glancesApp.controller('statsController', function ($scope, $rootScope, $interval
             $scope.statsAlert = GlancesStats.getPlugin('alert');
             $scope.statsCpu = GlancesStats.getPlugin('cpu');
             $scope.statsDiskio = GlancesStats.getPlugin('diskio');
+	    $scope.statsIrq = GlancesStats.getPlugin('irq');
             $scope.statsDocker = GlancesStats.getPlugin('docker');
             $scope.statsFs = GlancesStats.getPlugin('fs');
+            $scope.statsFolders = GlancesStats.getPlugin('folders');
             $scope.statsIp = GlancesStats.getPlugin('ip');
             $scope.statsLoad = GlancesStats.getPlugin('load');
             $scope.statsMem = GlancesStats.getPlugin('mem');
             $scope.statsMemSwap = GlancesStats.getPlugin('memswap');
-            $scope.statsMonitor = GlancesStats.getPlugin('monitor');
+            $scope.statsAmps = GlancesStats.getPlugin('amps');
             $scope.statsNetwork = GlancesStats.getPlugin('network');
             $scope.statsPerCpu = GlancesStats.getPlugin('percpu');
             $scope.statsProcessCount = GlancesStats.getPlugin('processcount');
@@ -40,6 +42,7 @@ glancesApp.controller('statsController', function ($scope, $rootScope, $interval
             $scope.statsSensors = GlancesStats.getPlugin('sensors');
             $scope.statsSystem = GlancesStats.getPlugin('system');
             $scope.statsUptime = GlancesStats.getPlugin('uptime');
+            $scope.statsPorts = GlancesStats.getPlugin('ports');
 
             $rootScope.title = $scope.statsSystem.hostname + ' - Glances';
 
@@ -63,6 +66,10 @@ glancesApp.controller('statsController', function ($scope, $rootScope, $interval
                 $scope.sorter.column = "cpu_percent";
                 $scope.sorter.auto = true;
                 break;
+            case $event.shiftKey && $event.keyCode == keycodes.A:
+                // A => Enable/disable AMPs
+                $scope.arguments.disable_amps = !$scope.arguments.disable_amps;
+                break;
             case !$event.shiftKey && $event.keyCode == keycodes.c:
                 // c => Sort processes by CPU%
                 $scope.sorter.column = "cpu_percent";
@@ -97,6 +104,10 @@ glancesApp.controller('statsController', function ($scope, $rootScope, $interval
                 // d => Show/hide disk I/O stats
                 $scope.arguments.disable_diskio = !$scope.arguments.disable_diskio;
                 break;
+	    case $event.shiftKey && $event.keyCode == keycodes.Q:
+                // R => Show/hide IRQ
+                $scope.arguments.disable_irq = !$scope.arguments.disable_irq;
+                break;
             case !$event.shiftKey && $event.keyCode == keycodes.f:
                 // f => Show/hide filesystem stats
                 $scope.arguments.disable_fs = !$scope.arguments.disable_fs;
@@ -172,6 +183,10 @@ glancesApp.controller('statsController', function ($scope, $rootScope, $interval
                 // I => Show/hide IP module
                 $scope.arguments.disable_ip = !$scope.arguments.disable_ip;
                 break;
+            case $event.shiftKey && $event.keyCode == keycodes.p:
+                // I => Enable/disable ports module
+                $scope.arguments.disable_ports = !$scope.arguments.disable_ports;
+                break;
         }
     };
 });
