@@ -28,5 +28,7 @@ var keycodes = {
 	'F' : '70',
 	'g' : '71',
 	'r' : '82',
-	'q' : '81'
+	'q' : '81',
+	'A' : '65',
+	'R' : '82',
 }
