@@ -59,7 +59,9 @@ snmp_oid['esxi'] = snmp_oid['windows']
 # Define the history items list
 # All items in this list will be historised if the --enable-history tag is set
 # 'color' define the graph color in #RGB format
-items_history_list = [{'name': 'percent', 'color': '#00FF00'}]
+items_history_list = [{'name': 'percent',
+                       'description': 'File system usage in percent',
+                       'color': '#00FF00'}]
 
 
 class Plugin(GlancesPlugin):
@@ -214,14 +216,14 @@ class Plugin(GlancesPlugin):
 
         # Build the string message
         # Header
-        msg = '{0:{width}}'.format('FILE SYS', width=fsname_max_width)
+        msg = '{:{width}}'.format('FILE SYS', width=fsname_max_width)
         ret.append(self.curse_add_line(msg, "TITLE"))
         if args.fs_free_space:
-            msg = '{0:>7}'.format('Free')
+            msg = '{:>7}'.format('Free')
         else:
-            msg = '{0:>7}'.format('Used')
+            msg = '{:>7}'.format('Used')
         ret.append(self.curse_add_line(msg))
-        msg = '{0:>7}'.format('Total')
+        msg = '{:>7}'.format('Total')
         ret.append(self.curse_add_line(msg))
 
         # Filesystem list (sorted by name)
@@ -239,16 +241,16 @@ class Plugin(GlancesPlugin):
                 mnt_point = '_' + i['mnt_point'][-fsname_max_width + 1:]
             else:
                 mnt_point = i['mnt_point']
-            msg = '{0:{width}}'.format(mnt_point, width=fsname_max_width)
+            msg = '{:{width}}'.format(mnt_point, width=fsname_max_width)
             ret.append(self.curse_add_line(msg))
             if args.fs_free_space:
-                msg = '{0:>7}'.format(self.auto_unit(i['free']))
+                msg = '{:>7}'.format(self.auto_unit(i['free']))
             else:
-                msg = '{0:>7}'.format(self.auto_unit(i['used']))
+                msg = '{:>7}'.format(self.auto_unit(i['used']))
             ret.append(self.curse_add_line(msg, self.get_views(item=i[self.get_key()],
                                                                key='used',
                                                                option='decoration')))
-            msg = '{0:>7}'.format(self.auto_unit(i['size']))
+            msg = '{:>7}'.format(self.auto_unit(i['size']))
             ret.append(self.curse_add_line(msg))
 
         return ret
