@@ -36,9 +36,15 @@ snmp_oid = {'min1': '1.3.6.1.4.1.2021.10.1.3.1',
 # Define the history items list
 # All items in this list will be historised if the --enable-history tag is set
 # 'color' define the graph color in #RGB format
-items_history_list = [{'name': 'min1', 'color': '#0000FF'},
-                      {'name': 'min5', 'color': '#0000AA'},
-                      {'name': 'min15', 'color': '#000044'}]
+items_history_list = [{'name': 'min1',
+                       'description': '1 minute load',
+                       'color': '#0000FF'},
+                      {'name': 'min5',
+                       'description': '5 minutes load',
+                       'color': '#0000AA'},
+                      {'name': 'min15',
+                       'description': '15 minutes load',
+                       'color': '#000044'}]
 
 
 class Plugin(GlancesPlugin):
@@ -62,7 +68,7 @@ class Plugin(GlancesPlugin):
         try:
             self.nb_log_core = CorePlugin(args=self.args).update()["log"]
         except Exception:
-            self.nb_log_core = 0
+            self.nb_log_core = 1
 
     def reset(self):
         """Reset/init the stats."""
@@ -130,39 +136,39 @@ class Plugin(GlancesPlugin):
         # Init the return message
         ret = []
 
-        # Only process if stats exist and plugin not disabled
-        if not self.stats or args.disable_load:
+        # Only process if stats exist, not empty (issue #871) and plugin not disabled
+        if not self.stats or (self.stats == {}) or args.disable_load:
             return ret
 
         # Build the string message
         # Header
-        msg = '{0:8}'.format('LOAD')
+        msg = '{:8}'.format('LOAD')
         ret.append(self.curse_add_line(msg, "TITLE"))
         # Core number
         if 'cpucore' in self.stats and self.stats['cpucore'] > 0:
-            msg = '{0}-core'.format(int(self.stats['cpucore']))
+            msg = '{}-core'.format(int(self.stats['cpucore']))
             ret.append(self.curse_add_line(msg))
         # New line
         ret.append(self.curse_new_line())
         # 1min load
-        msg = '{0:8}'.format('1 min:')
+        msg = '{:8}'.format('1 min:')
         ret.append(self.curse_add_line(msg))
-        msg = '{0:>6.2f}'.format(self.stats['min1'])
+        msg = '{:>6.2f}'.format(self.stats['min1'])
         ret.append(self.curse_add_line(msg))
         # New line
         ret.append(self.curse_new_line())
         # 5min load
-        msg = '{0:8}'.format('5 min:')
+        msg = '{:8}'.format('5 min:')
         ret.append(self.curse_add_line(msg))
-        msg = '{0:>6.2f}'.format(self.stats['min5'])
+        msg = '{:>6.2f}'.format(self.stats['min5'])
         ret.append(self.curse_add_line(
             msg, self.get_views(key='min5', option='decoration')))
         # New line
         ret.append(self.curse_new_line())
         # 15min load
-        msg = '{0:8}'.format('15 min:')
+        msg = '{:8}'.format('15 min:')
         ret.append(self.curse_add_line(msg))
-        msg = '{0:>6.2f}'.format(self.stats['min15'])
+        msg = '{:>6.2f}'.format(self.stats['min15'])
         ret.append(self.curse_add_line(
             msg, self.get_views(key='min15', option='decoration')))
 
