@@ -37,7 +37,10 @@ snmp_oid = {'default': {'total': '1.3.6.1.4.1.2021.4.3.0',
 # Define the history items list
 # All items in this list will be historised if the --enable-history tag is set
 # 'color' define the graph color in #RGB format
-items_history_list = [{'name': 'percent', 'color': '#00FF00', 'y_unit': '%'}]
+items_history_list = [{'name': 'percent',
+                       'description': 'Swap memory usage',
+                       'color': '#00FF00',
+                       'y_unit': '%'}]
 
 
 class Plugin(GlancesPlugin):
@@ -156,32 +159,32 @@ class Plugin(GlancesPlugin):
 
         # Build the string message
         # Header
-        msg = '{0:7} '.format('SWAP')
+        msg = '{:7} '.format('SWAP')
         ret.append(self.curse_add_line(msg, "TITLE"))
         # Percent memory usage
-        msg = '{0:>6.1%}'.format(self.stats['percent'] / 100)
+        msg = '{:>6.1%}'.format(self.stats['percent'] / 100)
         ret.append(self.curse_add_line(msg))
         # New line
         ret.append(self.curse_new_line())
         # Total memory usage
-        msg = '{0:8}'.format('total:')
+        msg = '{:8}'.format('total:')
         ret.append(self.curse_add_line(msg))
-        msg = '{0:>6}'.format(self.auto_unit(self.stats['total']))
+        msg = '{:>6}'.format(self.auto_unit(self.stats['total']))
         ret.append(self.curse_add_line(msg))
         # New line
         ret.append(self.curse_new_line())
         # Used memory usage
-        msg = '{0:8}'.format('used:')
+        msg = '{:8}'.format('used:')
         ret.append(self.curse_add_line(msg))
-        msg = '{0:>6}'.format(self.auto_unit(self.stats['used']))
+        msg = '{:>6}'.format(self.auto_unit(self.stats['used']))
         ret.append(self.curse_add_line(
             msg, self.get_views(key='used', option='decoration')))
         # New line
         ret.append(self.curse_new_line())
         # Free memory usage
-        msg = '{0:8}'.format('free:')
+        msg = '{:8}'.format('free:')
         ret.append(self.curse_add_line(msg))
-        msg = '{0:>6}'.format(self.auto_unit(self.stats['free']))
+        msg = '{:>6}'.format(self.auto_unit(self.stats['free']))
         ret.append(self.curse_add_line(msg))
 
         return ret
