@@ -37,8 +37,14 @@ snmp_oid = {'default': {'interface_name': '1.3.6.1.2.1.2.2.1.2',
 # Define the history items list
 # All items in this list will be historised if the --enable-history tag is set
 # 'color' define the graph color in #RGB format
-items_history_list = [{'name': 'rx', 'color': '#00FF00', 'y_unit': 'bit/s'},
-                      {'name': 'tx', 'color': '#FF0000', 'y_unit': 'bit/s'}]
+items_history_list = [{'name': 'rx',
+                       'description': 'Download rate per second',
+                       'color': '#00FF00',
+                       'y_unit': 'bit/s'},
+                      {'name': 'tx',
+                       'description': 'Upload rate per second',
+                       'color': '#FF0000',
+                       'y_unit': 'bit/s'}]
 
 
 class Plugin(GlancesPlugin):
@@ -88,7 +94,7 @@ class Plugin(GlancesPlugin):
             netstatus = {}
             try:
                 netstatus = psutil.net_if_stats()
-            except AttributeError:
+            except:
                 pass
 
             # Previous network interface stats are stored in the network_old variable
@@ -246,30 +252,30 @@ class Plugin(GlancesPlugin):
 
         # Build the string message
         # Header
-        msg = '{0:{width}}'.format('NETWORK', width=ifname_max_width)
+        msg = '{:{width}}'.format('NETWORK', width=ifname_max_width)
         ret.append(self.curse_add_line(msg, "TITLE"))
         if args.network_cumul:
             # Cumulative stats
             if args.network_sum:
                 # Sum stats
-                msg = '{0:>14}'.format('Rx+Tx')
+                msg = '{:>14}'.format('Rx+Tx')
                 ret.append(self.curse_add_line(msg))
             else:
                 # Rx/Tx stats
-                msg = '{0:>7}'.format('Rx')
+                msg = '{:>7}'.format('Rx')
                 ret.append(self.curse_add_line(msg))
-                msg = '{0:>7}'.format('Tx')
+                msg = '{:>7}'.format('Tx')
                 ret.append(self.curse_add_line(msg))
         else:
             # Bitrate stats
             if args.network_sum:
                 # Sum stats
-                msg = '{0:>14}'.format('Rx+Tx/s')
+                msg = '{:>14}'.format('Rx+Tx/s')
                 ret.append(self.curse_add_line(msg))
             else:
-                msg = '{0:>7}'.format('Rx/s')
+                msg = '{:>7}'.format('Rx/s')
                 ret.append(self.curse_add_line(msg))
-                msg = '{0:>7}'.format('Tx/s')
+                msg = '{:>7}'.format('Tx/s')
                 ret.append(self.curse_add_line(msg))
         # Interface list (sorted by name)
         for i in sorted(self.stats, key=operator.itemgetter(self.get_key())):
@@ -285,42 +291,39 @@ class Plugin(GlancesPlugin):
             if len(ifname) > ifname_max_width:
                 # Cut interface name if it is too long
                 ifname = '_' + ifname[-ifname_max_width + 1:]
+
             if args.byte:
                 # Bytes per second (for dummy)
-                if args.network_cumul:
-                    rx = self.auto_unit(int(i['cumulative_rx']))
-                    tx = self.auto_unit(int(i['cumulative_tx']))
-                    sx = self.auto_unit(int(i['cumulative_tx']) +
-                                        int(i['cumulative_tx']))
-                else:
-                    rx = self.auto_unit(int(i['rx'] // i['time_since_update']))
-                    tx = self.auto_unit(int(i['tx'] // i['time_since_update']))
-                    sx = self.auto_unit(int(i['rx'] // i['time_since_update']) +
-                                        int(i['tx'] // i['time_since_update']))
+                to_bit = 1
+                unit = ''
             else:
                 # Bits per second (for real network administrator | Default)
-                if args.network_cumul:
-                    rx = self.auto_unit(int(i['cumulative_rx'] * 8)) + "b"
-                    tx = self.auto_unit(int(i['cumulative_tx'] * 8)) + "b"
-                    sx = self.auto_unit(int(i['cumulative_rx'] * 8) +
-                                        int(i['cumulative_tx'] * 8)) + "b"
-                else:
-                    rx = self.auto_unit(int(i['rx'] // i['time_since_update'] * 8)) + "b"
-                    tx = self.auto_unit(int(i['tx'] // i['time_since_update'] * 8)) + "b"
-                    sx = self.auto_unit(int(i['rx'] // i['time_since_update'] * 8) +
-                                        int(i['tx'] // i['time_since_update'] * 8)) + "b"
+                to_bit = 8
+                unit = 'b'
+
+            if args.network_cumul:
+                rx = self.auto_unit(int(i['cumulative_rx'] * to_bit)) + unit
+                tx = self.auto_unit(int(i['cumulative_tx'] * to_bit)) + unit
+                sx = self.auto_unit(int(i['cumulative_rx'] * to_bit) +
+                                    int(i['cumulative_tx'] * to_bit)) + unit
+            else:
+                rx = self.auto_unit(int(i['rx'] // i['time_since_update'] * to_bit)) + unit
+                tx = self.auto_unit(int(i['tx'] // i['time_since_update'] * to_bit)) + unit
+                sx = self.auto_unit(int(i['rx'] // i['time_since_update'] * to_bit) +
+                                    int(i['tx'] // i['time_since_update'] * to_bit)) + unit
+
             # New line
             ret.append(self.curse_new_line())
-            msg = '{0:{width}}'.format(ifname, width=ifname_max_width)
+            msg = '{:{width}}'.format(ifname, width=ifname_max_width)
             ret.append(self.curse_add_line(msg))
             if args.network_sum:
-                msg = '{0:>14}'.format(sx)
+                msg = '{:>14}'.format(sx)
                 ret.append(self.curse_add_line(msg))
             else:
-                msg = '{0:>7}'.format(rx)
+                msg = '{:>7}'.format(rx)
                 ret.append(self.curse_add_line(
                     msg, self.get_views(item=i[self.get_key()], key='rx', option='decoration')))
-                msg = '{0:>7}'.format(tx)
+                msg = '{:>7}'.format(tx)
                 ret.append(self.curse_add_line(
                     msg, self.get_views(item=i[self.get_key()], key='tx', option='decoration')))
 
