@@ -17,10 +17,8 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-# Import system libs
 from datetime import datetime
 
-# Import Glances libs
 from glances.plugins.glances_plugin import GlancesPlugin
 
 
@@ -33,7 +31,7 @@ class Plugin(GlancesPlugin):
 
     def __init__(self, args=None):
         """Init the plugin."""
-        GlancesPlugin.__init__(self, args=args)
+        super(Plugin, self).__init__(args=args)
 
         # We want to display the stat in the curse interface
         self.display_curse = True
@@ -55,7 +53,7 @@ class Plugin(GlancesPlugin):
 
         # Build the string message
         # 23 is the padding for the process list
-        msg = '{0:23}'.format(self.stats)
+        msg = '{:23}'.format(self.stats)
         ret.append(self.curse_add_line(msg))
 
         return ret
