@@ -25,11 +25,11 @@ I am your father...
 
 import re
 import json
-from datetime import datetime
 from operator import itemgetter
 
 from glances.compat import iterkeys, itervalues, listkeys, map
 from glances.actions import GlancesActions
+from glances.history import GlancesHistory
 from glances.logger import logger
 from glances.logs import glances_logs
 
@@ -72,7 +72,7 @@ class GlancesPlugin(object):
 
     def exit(self):
         """Method to be called when Glances exit"""
-        logger.debug("Stop the {0} plugin".format(self.plugin_name))
+        logger.debug("Stop the {} plugin".format(self.plugin_name))
 
     def __repr__(self):
         """Return the raw stats."""
@@ -86,56 +86,116 @@ class GlancesPlugin(object):
         """Return the key of the list."""
         return None
 
-    def add_item_history(self, key, value):
-        """Add an new item (key, value) to the current history."""
+    def _json_dumps(self, d):
+        """Return the object 'd' in a JSON format
+        Manage the issue #815 for Windows OS"""
         try:
-            self.stats_history[key].append(value)
-        except KeyError:
-            self.stats_history[key] = [value]
+            return json.dumps(d)
+        except UnicodeDecodeError:
+            return json.dumps(d, ensure_ascii=False)
+
+    def _history_enable(self):
+        return self.args is not None and not self.args.disable_history and self.get_items_history_list() is not None
 
     def init_stats_history(self):
-        """Init the stats history (dict of list)."""
-        ret = None
-        if self.args is not None and self.args.enable_history and self.get_items_history_list() is not None:
-            init_list = [i['name'] for i in self.get_items_history_list()]
+        """Init the stats history (dict of GlancesAttribute)."""
+        if self._history_enable():
+            init_list = [a['name'] for a in self.get_items_history_list()]
             logger.debug("Stats history activated for plugin {0} (items: {1})".format(self.plugin_name, init_list))
-            ret = {}
-        return ret
+        return GlancesHistory()
 
     def reset_stats_history(self):
-        """Reset the stats history (dict of list)."""
-        if self.args is not None and self.args.enable_history and self.get_items_history_list() is not None:
-            reset_list = [i['name'] for i in self.get_items_history_list()]
+        """Reset the stats history (dict of GlancesAttribute)."""
+        if self._history_enable():
+            reset_list = [a['name'] for a in self.get_items_history_list()]
             logger.debug("Reset history for plugin {0} (items: {1})".format(self.plugin_name, reset_list))
-            self.stats_history = {}
+            self.stats_history.reset()
 
     def update_stats_history(self, item_name=''):
         """Update stats history."""
-        if (self.stats and self.args is not None and
-                self.args.enable_history and
-                self.get_items_history_list() is not None):
-            self.add_item_history('date', datetime.now())
+        if self.stats and self._history_enable():
             for i in self.get_items_history_list():
                 if isinstance(self.stats, list):
                     # Stats is a list of data
                     # Iter throught it (for exemple, iter throught network
                     # interface)
                     for l in self.stats:
-                        self.add_item_history(
-                            l[item_name] + '_' + i['name'], l[i['name']])
+                        self.stats_history.add(
+                            l[item_name] + '_' + i['name'],
+                            l[i['name']],
+                            description=i['description'],
+                            history_max_size=self._limits['history_size'])
                 else:
                     # Stats is not a list
                     # Add the item to the history directly
-                    self.add_item_history(i['name'], self.stats[i['name']])
-
-    def get_stats_history(self):
-        """Return the stats history."""
-        return self.stats_history
+                    self.stats_history.add(i['name'],
+                                           self.stats[i['name']],
+                                           description=i['description'],
+                                           history_max_size=self._limits['history_size'])
 
     def get_items_history_list(self):
         """Return the items history list."""
         return self.items_history_list
 
+    def get_raw_history(self, item=None):
+        """Return
+        - the stats history (dict of list) if item is None
+        - the stats history for the given item (list) instead
+        - None if item did not exist in the history"""
+        s = self.stats_history.get()
+        if item is None:
+            return s
+        else:
+            if item in s:
+                return s[item]
+            else:
+                return None
+
+    def get_json_history(self, item=None, nb=0):
+        """Return:
+        - the stats history (dict of list) if item is None
+        - the stats history for the given item (list) instead
+        - None if item did not exist in the history
+        Limit to lasts nb items (all if nb=0)"""
+        s = self.stats_history.get_json(nb=nb)
+        if item is None:
+            return s
+        else:
+            if item in s:
+                return s[item]
+            else:
+                return None
+
+    def get_export_history(self, item=None):
+        """Return the stats history object to export.
+        See get_raw_history for a full description"""
+        return self.get_raw_history(item=item)
+
+    def get_stats_history(self, item=None, nb=0):
+        """Return the stats history as a JSON object (dict or None).
+        Limit to lasts nb items (all if nb=0)"""
+        s = self.get_json_history(nb=nb)
+
+        if item is None:
+            return self._json_dumps(s)
+
+        if isinstance(s, dict):
+            try:
+                return self._json_dumps({item: s[item]})
+            except KeyError as e:
+                logger.error("Cannot get item history {0} ({1})".format(item, e))
+                return None
+        elif isinstance(s, list):
+            try:
+                # Source:
+                # http://stackoverflow.com/questions/4573875/python-get-index-of-dictionary-item-in-list
+                return self._json_dumps({item: map(itemgetter(item), s)})
+            except (KeyError, ValueError) as e:
+                logger.error("Cannot get item history {0} ({1})".format(item, e))
+                return None
+        else:
+            return None
+
     @property
     def input_method(self):
         """Get the input method."""
@@ -230,7 +290,7 @@ class GlancesPlugin(object):
 
     def get_stats(self):
         """Return the stats object in JSON format."""
-        return json.dumps(self.stats)
+        return self._json_dumps(self.stats)
 
     def get_stats_item(self, item):
         """Return the stats object for a specific item in JSON format.
@@ -239,17 +299,17 @@ class GlancesPlugin(object):
         """
         if isinstance(self.stats, dict):
             try:
-                return json.dumps({item: self.stats[item]})
+                return self._json_dumps({item: self.stats[item]})
             except KeyError as e:
-                logger.error("Cannot get item {0} ({1})".format(item, e))
+                logger.error("Cannot get item {} ({})".format(item, e))
                 return None
         elif isinstance(self.stats, list):
             try:
                 # Source:
                 # http://stackoverflow.com/questions/4573875/python-get-index-of-dictionary-item-in-list
-                return json.dumps({item: map(itemgetter(item), self.stats)})
+                return self._json_dumps({item: map(itemgetter(item), self.stats)})
             except (KeyError, ValueError) as e:
-                logger.error("Cannot get item {0} ({1})".format(item, e))
+                logger.error("Cannot get item {} ({})".format(item, e))
                 return None
         else:
             return None
@@ -265,10 +325,10 @@ class GlancesPlugin(object):
             if value.isdigit():
                 value = int(value)
             try:
-                return json.dumps({value: [i for i in self.stats if i[item] == value]})
+                return self._json_dumps({value: [i for i in self.stats if i[item] == value]})
             except (KeyError, ValueError) as e:
                 logger.error(
-                    "Cannot get item({0})=value({1}) ({2})".format(item, value, e))
+                    "Cannot get item({})=value({}) ({})".format(item, value, e))
                 return None
 
     def update_views(self):
@@ -337,8 +397,20 @@ class GlancesPlugin(object):
 
     def load_limits(self, config):
         """Load limits from the configuration file, if it exists."""
-        if (hasattr(config, 'has_section') and
-                config.has_section(self.plugin_name)):
+
+        # By default set the history length to 3 points per second during one day
+        self._limits['history_size'] = 28800
+
+        if not hasattr(config, 'has_section'):
+            return False
+
+        # Read the global section
+        if config.has_section('global'):
+            self._limits['history_size'] = config.get_float_value('global', 'history_size', default=28800)
+            logger.debug("Load configuration key: {0} = {1}".format('history_size', self._limits['history_size']))
+
+        # Read the plugin specific section
+        if config.has_section(self.plugin_name):
             for level, _ in config.items(self.plugin_name):
                 # Read limits
                 limit = '_'.join([self.plugin_name, level])
@@ -346,7 +418,9 @@ class GlancesPlugin(object):
                     self._limits[limit] = config.get_float_value(self.plugin_name, level)
                 except ValueError:
                     self._limits[limit] = config.get_value(self.plugin_name, level).split(",")
-                logger.debug("Load limit: {0} = {1}".format(limit, self._limits[limit]))
+                logger.debug("Load limit: {} = {}".format(limit, self._limits[limit]))
+
+        return True
 
     @property
     def limits(self):
@@ -410,7 +484,7 @@ class GlancesPlugin(object):
             # So stats will be highlited with a specific color
             log_str = "_LOG"
             # Add the log to the list
-            glances_logs.add(ret, stat_name.upper(), value, [])
+            glances_logs.add(ret, stat_name.upper(), value)
 
         # Manage action
         # Here is a command line for the current trigger ?
@@ -455,6 +529,8 @@ class GlancesPlugin(object):
             # Exemple: network_careful
             limit = self._limits[self.plugin_name + '_' + criticity]
 
+        # logger.debug("{} {} value is {}".format(stat_name, criticity, limit))
+
         # Return the limit
         return limit
 
@@ -648,9 +724,9 @@ class GlancesPlugin(object):
                         decimal_precision = min(1, decimal_precision)
                 elif symbol in 'K':
                     decimal_precision = 0
-                return '{0:.{decimal}f}{symbol}'.format(
+                return '{:.{decimal}f}{symbol}'.format(
                     value, decimal=decimal_precision, symbol=symbol)
-        return '{0!s}'.format(number)
+        return '{!s}'.format(number)
 
     def _log_result_decorator(fct):
         """Log (DEBUG) the result of the function fct."""
