@@ -80,9 +80,11 @@ class Plugin(GlancesPlugin):
         # thanks to the cpuinfo lib: https://github.com/workhorsy/py-cpuinfo
         if cpuinfo_tag:
             cpu_info = cpuinfo.get_cpu_info()
-            self.stats['cpu_name'] = cpu_info['brand']
-            self.stats['cpu_hz_current'] = cpu_info['hz_actual_raw'][0]
-            self.stats['cpu_hz'] = cpu_info['hz_advertised_raw'][0]
+            #  Check cpu_info (issue #881)
+            if cpu_info is not None:
+                self.stats['cpu_name'] = cpu_info['brand']
+                self.stats['cpu_hz_current'] = cpu_info['hz_actual_raw'][0]
+                self.stats['cpu_hz'] = cpu_info['hz_advertised_raw'][0]
 
         # Update the view
         self.update_views()
@@ -113,40 +115,44 @@ class Plugin(GlancesPlugin):
         bar = Bar(max_width)
 
         # Build the string message
-        if 'cpu_name' in self.stats:
-            msg = '{0} - {1:.2f}/{2:.2f}GHz'.format(self.stats['cpu_name'],
-                                                    self._hz_to_ghz(self.stats['cpu_hz_current']),
-                                                    self._hz_to_ghz(self.stats['cpu_hz']))
-            if len(msg) - 6 <= max_width:
-                ret.append(self.curse_add_line(msg))
-                ret.append(self.curse_new_line())
+        if 'cpu_name' in self.stats and 'cpu_hz_current' in self.stats and 'cpu_hz' in self.stats:
+            msg_name = '{} - '.format(self.stats['cpu_name'])
+            msg_freq = '{:.2f}/{:.2f}GHz'.format(self._hz_to_ghz(self.stats['cpu_hz_current']),
+                                                 self._hz_to_ghz(self.stats['cpu_hz']))
+            if len(msg_name + msg_freq) - 6 <= max_width:
+                ret.append(self.curse_add_line(msg_name))
+            ret.append(self.curse_add_line(msg_freq))
+            ret.append(self.curse_new_line())
         for key in ['cpu', 'mem', 'swap']:
             if key == 'cpu' and args.percpu:
                 for cpu in self.stats['percpu']:
                     bar.percent = cpu['total']
                     if cpu[cpu['key']] < 10:
-                        msg = '{0:3}{1} '.format(key.upper(), cpu['cpu_number'])
+                        msg = '{:3}{} '.format(key.upper(), cpu['cpu_number'])
                     else:
-                        msg = '{0:4} '.format(cpu['cpu_number'])
-                    ret.append(self.curse_add_line(msg))
-                    ret.append(self.curse_add_line(bar.pre_char, decoration='BOLD'))
-                    ret.append(self.curse_add_line(str(bar), self.get_views(key=key, option='decoration')))
-                    ret.append(self.curse_add_line(bar.post_char, decoration='BOLD'))
-                    ret.append(self.curse_add_line('  '))
-                    ret.append(self.curse_new_line())
+                        msg = '{:4} '.format(cpu['cpu_number'])
+                    ret.extend(self._msg_create_line(msg, bar, key))
             else:
                 bar.percent = self.stats[key]
-                msg = '{0:4} '.format(key.upper())
-                ret.append(self.curse_add_line(msg))
-                ret.append(self.curse_add_line(bar.pre_char, decoration='BOLD'))
-                ret.append(self.curse_add_line(str(bar), self.get_views(key=key, option='decoration')))
-                ret.append(self.curse_add_line(bar.post_char, decoration='BOLD'))
-                ret.append(self.curse_add_line('  '))
-                ret.append(self.curse_new_line())
+                msg = '{:4} '.format(key.upper())
+                ret.extend(self._msg_create_line(msg, bar, key))
 
         # Return the message with decoration
         return ret
 
+    def _msg_create_line(self, msg, bar, key):
+        """Create a new line to the Quickview"""
+        ret = []
+
+        ret.append(self.curse_add_line(msg))
+        ret.append(self.curse_add_line(bar.pre_char, decoration='BOLD'))
+        ret.append(self.curse_add_line(str(bar), self.get_views(key=key, option='decoration')))
+        ret.append(self.curse_add_line(bar.post_char, decoration='BOLD'))
+        ret.append(self.curse_add_line('  '))
+        ret.append(self.curse_new_line())
+
+        return ret
+
     def _hz_to_ghz(self, hz):
         """Convert Hz to Ghz"""
         return hz / 1000000000.0
