@@ -179,22 +179,31 @@ class Plugin(GlancesPlugin):
 
         # Build the string message
         # Header
-        msg = '{0:18}'.format('SENSORS')
+        msg = '{:18}'.format('SENSORS')
         ret.append(self.curse_add_line(msg, "TITLE"))
 
         for i in self.stats:
-            if i['value'] != b'ERR':
-                # New line
-                ret.append(self.curse_new_line())
-                # Alias for the lable name ?
-                label = self.has_alias(i['label'].lower())
-                if label is None:
-                    label = i['label']
-                if i['type'] != 'fan_speed':
-                    msg = '{0:15}'.format(label[:15])
-                else:
-                    msg = '{0:13}'.format(label[:13])
-                ret.append(self.curse_add_line(msg))
+            # Do not display anything if no battery are detected
+            if (i['type'] == 'battery' and i['value'] == []):
+                continue
+            # New line
+            ret.append(self.curse_new_line())
+            # Alias for the lable name ?
+            label = self.has_alias(i['label'].lower())
+            if label is None:
+                label = i['label']
+            if i['type'] != 'fan_speed':
+                msg = '{:15}'.format(label[:15])
+            else:
+                msg = '{:13}'.format(label[:13])
+            ret.append(self.curse_add_line(msg))
+            if i['value'] in (b'ERR', b'SLP', b'UNK', b'NOS'):
+                msg = '{:>8}'.format(i['value'])
+                ret.append(self.curse_add_line(
+                    msg, self.get_views(item=i[self.get_key()],
+                                        key='value',
+                                        option='decoration')))
+            else:
                 if (args.fahrenheit and i['type'] != 'battery' and
                         i['type'] != 'fan_speed'):
                     value = to_fahrenheit(i['value'])
@@ -203,7 +212,7 @@ class Plugin(GlancesPlugin):
                     value = i['value']
                     unit = i['unit']
                 try:
-                    msg = '{0:>7.0f}{1}'.format(value, unit)
+                    msg = '{:>7.0f}{}'.format(value, unit)
                     ret.append(self.curse_add_line(
                         msg, self.get_views(item=i[self.get_key()],
                                             key='value',
