@@ -17,14 +17,16 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
+import operator
 import os
 import re
 
 from glances.compat import iteritems, itervalues, listitems
 from glances.globals import BSD, LINUX, OSX, WINDOWS
-from glances.logger import logger
 from glances.timer import Timer, getTimeSinceLastUpdate
 from glances.processes_tree import ProcessTreeNode
+from glances.filter import GlancesFilter
+from glances.logger import logger
 
 import psutil
 
@@ -81,8 +83,7 @@ class GlancesProcesses(object):
         self._max_processes = None
 
         # Process filter is a regular expression
-        self._process_filter = None
-        self._process_filter_re = None
+        self._filter = GlancesFilter()
 
         # Whether or not to hide kernel threads
         self.no_kernel_threads = False
@@ -115,42 +116,30 @@ class GlancesProcesses(object):
         """Set the maximum number of processes showed in the UI."""
         self._max_processes = value
 
+    @property
+    def process_filter_input(self):
+        """Get the process filter (given by the user)."""
+        return self._filter.filter_input
+
     @property
     def process_filter(self):
-        """Get the process filter."""
-        return self._process_filter
+        """Get the process filter (current apply filter)."""
+        return self._filter.filter
 
     @process_filter.setter
     def process_filter(self, value):
         """Set the process filter."""
-        logger.info("Set process filter to {0}".format(value))
-        self._process_filter = value
-        if value is not None:
-            try:
-                self._process_filter_re = re.compile(value)
-                logger.debug("Process filter regex compilation OK: {0}".format(self.process_filter))
-            except Exception:
-                logger.error("Cannot compile process filter regex: {0}".format(value))
-                self._process_filter_re = None
-        else:
-            self._process_filter_re = None
+        self._filter.filter = value
+
+    @property
+    def process_filter_key(self):
+        """Get the process filter key."""
+        return self._filter.filter_key
 
     @property
     def process_filter_re(self):
         """Get the process regular expression compiled."""
-        return self._process_filter_re
-
-    def is_filtered(self, value):
-        """Return True if the value should be filtered."""
-        if self.process_filter is None:
-            # No filter => Not filtered
-            return False
-        else:
-            try:
-                return self.process_filter_re.match(' '.join(value)) is None
-            except AttributeError:
-                #  Filter processes crashs with a bad regular expression pattern (issue #665)
-                return False
+        return self._filter.filter_re
 
     def disable_kernel_threads(self):
         """Ignore kernel threads in process list."""
@@ -290,11 +279,17 @@ class GlancesProcesses(object):
             procstat['cpu_affinity'] = None
         # Memory extended
         try:
-            procstat.update(proc.as_dict(attrs=['memory_info_ex']))
+            procstat.update(proc.as_dict(attrs=['memory_full_info']))
         except psutil.NoSuchProcess:
             pass
         except AttributeError:
-            procstat['memory_info_ex'] = None
+            # Fallback to standard memory_info stats
+            try:
+                procstat.update(proc.as_dict(attrs=['memory_info']))
+            except psutil.NoSuchProcess:
+                pass
+            except AttributeError:
+                procstat['memory_info'] = None
         # Number of context switch
         try:
             procstat.update(proc.as_dict(attrs=['num_ctx_switches']))
@@ -400,24 +395,27 @@ class GlancesProcesses(object):
             if self.no_kernel_threads and not WINDOWS and is_kernel_thread(proc):
                 continue
 
-            # If self.max_processes is None: Only retreive mandatory stats
-            # Else: retreive mandatory and standard stats
+            # If self.max_processes is None: Only retrieve mandatory stats
+            # Else: retrieve mandatory and standard stats
             s = self.__get_process_stats(proc,
                                          mandatory_stats=True,
                                          standard_stats=self.max_processes is None)
-            # Continue to the next process if it has to be filtered
-            if s is None or (self.is_filtered(s['cmdline']) and self.is_filtered(s['name'])):
-                excluded_processes.add(proc)
-                continue
-            # Ok add the process to the list
-            processdict[proc] = s
+            # Check if s is note None (issue #879)
             # ignore the 'idle' process on Windows and *BSD
             # ignore the 'kernel_task' process on OS X
             # waiting for upstream patch from psutil
-            if (BSD and processdict[proc]['name'] == 'idle' or
-                    WINDOWS and processdict[proc]['name'] == 'System Idle Process' or
-                    OSX and processdict[proc]['name'] == 'kernel_task'):
+            if (s is None or
+               BSD and s['name'] == 'idle' or
+               WINDOWS and s['name'] == 'System Idle Process' or
+               OSX and s['name'] == 'kernel_task'):
                 continue
+            # Continue to the next process if it has to be filtered
+            if self._filter.is_filtered(s):
+                excluded_processes.add(proc)
+                continue
+
+            # Ok add the process to the list
+            processdict[proc] = s
             # Update processcount (global statistics)
             try:
                 self.processcount[str(proc.status())] += 1
@@ -471,8 +469,8 @@ class GlancesProcesses(object):
                                          key=lambda x: x[1][self.sort_key],
                                          reverse=self.sort_reverse)
                 except (KeyError, TypeError) as e:
-                    logger.error("Cannot sort process list by {0}: {1}".format(self.sort_key, e))
-                    logger.error('{0}'.format(listitems(processdict)[0]))
+                    logger.error("Cannot sort process list by {}: {}".format(self.sort_key, e))
+                    logger.error('{}'.format(listitems(processdict)[0]))
                     # Fallback to all process (issue #423)
                     processloop = iteritems(processdict)
                     first = False
@@ -504,8 +502,8 @@ class GlancesProcesses(object):
                 # Next...
                 first = False
 
-        # Build the all processes list used by the monitored list
-        self.allprocesslist = itervalues(processdict)
+        # Build the all processes list used by the AMPs
+        self.allprocesslist = [p for p in itervalues(processdict)]
 
         # Clean internals caches if timeout is reached
         if self.cache_timer.finished():
@@ -540,4 +538,41 @@ class GlancesProcesses(object):
         """Set the current sort key."""
         self._sort_key = key
 
+
+# TODO: move this global function (also used in glances_processlist
+#       and logs) inside the GlancesProcesses class
+def sort_stats(stats, sortedby=None, tree=False, reverse=True):
+    """Return the stats (dict) sorted by (sortedby)
+    Reverse the sort if reverse is True."""
+    if sortedby is None:
+        # No need to sort...
+        return stats
+
+    if sortedby == 'io_counters' and not tree:
+        # Specific case for io_counters
+        # Sum of io_r + io_w
+        try:
+            # Sort process by IO rate (sum IO read + IO write)
+            stats.sort(key=lambda process: process[sortedby][0] -
+                       process[sortedby][2] + process[sortedby][1] -
+                       process[sortedby][3],
+                       reverse=reverse)
+        except Exception:
+            stats.sort(key=operator.itemgetter('cpu_percent'),
+                       reverse=reverse)
+    else:
+        # Others sorts
+        if tree:
+            stats.set_sorting(sortedby, reverse)
+        else:
+            try:
+                stats.sort(key=operator.itemgetter(sortedby),
+                           reverse=reverse)
+            except (KeyError, TypeError):
+                stats.sort(key=operator.itemgetter('name'),
+                           reverse=False)
+
+    return stats
+
+
 glances_processes = GlancesProcesses()
